@@ -47,6 +47,7 @@ class KMeans:
 
 		self._model_dict =None
 		self._env = None
+		self._features = None
 
 		self._evaluator = evaluator
 		self._raise_timeout = raise_timeout
@@ -60,6 +61,7 @@ class KMeans:
 		"""
 		:type X: PandasDF
 		"""
+		self._features = list(X.columns)
 		model = SklearnKMeans(
 			n_clusters=self.n_clusters, n_jobs=self._n_jobs, **self._kwargs
 		)
@@ -112,7 +114,10 @@ class KMeans:
 		:type prefix: str
 		:rtype: PandasDF
 		"""
-		result = PandasDF(self._python_model.transform(X=X), columns=[f'{prefix}{x + 1}' for x in range(self._n_clusters)])
+		result = PandasDF(
+			self._python_model.transform(X=X[self._features]),
+			columns=[f'{prefix}{x + 1}' for x in range(self._n_clusters)]
+		)
 		if isinstance(X, PandasDF):
 			result.index = X.index
 
@@ -135,7 +140,7 @@ class KMeans:
 		:type return_dataframe: bool
 		:rtype: PandasSeries or PandasDF
 		"""
-		ndarray = self._python_model.predict(X=X)
+		ndarray = self._python_model.predict(X=X[self._features])
 		series = PandasSeries(ndarray, name='prediction')
 		predictions = series.apply(lambda x: f'{prefix}{x + 1}')
 		if keep_columns:
@@ -161,8 +166,8 @@ class KMeans:
 		"""
 		:type X: SparkDF
 		"""
-		features = X.columns
-		assembler = VectorAssembler(inputCols=features, outputCol="features")
+		self._features = X.columns
+		assembler = VectorAssembler(inputCols=self._features, outputCol="features")
 		assembled = assembler.transform(X)
 		kmeans = SparkKMeans(k=self.n_clusters).fit(assembled.select('features'))
 		if self._evaluator is not None:
